@@ -1,16 +1,18 @@
 from __future__ import annotations
 
-from typing import NamedTuple, Union, List, Any, Dict, Optional
+import asyncio
+from queue import Queue
+from typing import Any, Dict, List, NamedTuple, Union
+
 import ansible_events.condition_types as ct
 
-import asyncio
-import multiprocessing as mp
 
 class EventSourceFilter(NamedTuple):
 
     filter_name: str
     filter_args: dict
 
+
 class EventSource(NamedTuple):
     name: str
     source_name: str
@@ -40,13 +42,6 @@ class RuleSet(NamedTuple):
     hosts: Union[str, List[str]]
     sources: List[EventSource]
     rules: List[Rule]
-    host_rules: List[Rule]
-
-
-class HostRuleSet(NamedTuple):
-    name: str
-    host: str
-    ruleset: RuleSet
 
 
 class ActionContext(NamedTuple):
@@ -64,12 +59,13 @@ class RuleSetPlan(NamedTuple):
     ruleset: RuleSet
     plan: asyncio.Queue
 
+
 class RuleSetQueue(NamedTuple):
     ruleset: RuleSet
-    queue: mp.Queue
+    queue: Queue
+
 
 class RuleSetQueuePlan(NamedTuple):
     ruleset: RuleSet
-    queue: mp.Queue
+    queue: Queue
     plan: asyncio.Queue
-
