@@ -1,9 +1,18 @@
+from typing import Any, Dict, List
+
 import ansible_events.rule_types as rt
-import ansible_events.condition_types as ct
+from ansible_events.condition_parser import (
+    parse_condition as parse_condition_value,
+)
 
-from ansible_events.condition_parser import parse_condition as parse_condition_value
 
-from typing import Dict, List, Any
+def parse_hosts(hosts):
+    if isinstance(hosts, str):
+        return [hosts]
+    elif isinstance(hosts, list):
+        return hosts
+    else:
+        raise Exception(f"Unsupported hosts value {hosts}")
 
 
 def parse_rule_sets(rule_sets: Dict) -> List[rt.RuleSet]:
@@ -12,10 +21,9 @@ def parse_rule_sets(rule_sets: Dict) -> List[rt.RuleSet]:
         rule_set_list.append(
             rt.RuleSet(
                 name=rule_set["name"],
-                hosts=rule_set["hosts"],
+                hosts=parse_hosts(rule_set["hosts"]),
                 sources=parse_event_sources(rule_set["sources"]),
                 rules=parse_rules(rule_set.get("rules", {})),
-                host_rules=parse_rules(rule_set.get("host_rules", {})),
             )
         )
     return rule_set_list
@@ -24,7 +32,7 @@ def parse_rule_sets(rule_sets: Dict) -> List[rt.RuleSet]:
 def parse_event_sources(sources: Dict) -> List[rt.EventSource]:
     source_list = []
     for source in sources:
-        name = source.pop("name", '')
+        name = source.pop("name", "")
         source_filters = []
         for source_filter in source.pop("filters", []):
             source_filters.append(parse_source_filter(source_filter))
@@ -47,12 +55,10 @@ def parse_event_sources(sources: Dict) -> List[rt.EventSource]:
 
 def parse_source_filter(source_filter: Dict) -> rt.EventSourceFilter:
 
-
     source_filter_name = list(source_filter.keys())[0]
     source_filter_args = source_filter[source_filter_name]
 
-    return rt.EventSourceFilter(source_filter_name,
-                             source_filter_args)
+    return rt.EventSourceFilter(source_filter_name, source_filter_args)
 
 
 def parse_rules(rules: Dict) -> List[rt.Rule]:
@@ -64,7 +70,7 @@ def parse_rules(rules: Dict) -> List[rt.Rule]:
                 name=name,
                 condition=parse_condition(rule["condition"]),
                 action=parse_action(rule["action"]),
-                enabled=rule.get('enabled', True)
+                enabled=rule.get("enabled", True),
             )
         )
 
@@ -82,14 +88,18 @@ def parse_action(action: Dict) -> rt.Action:
 
 def parse_condition(condition: Any) -> rt.Condition:
     if isinstance(condition, str):
-        return rt.Condition('all', [parse_condition_value(condition)])
+        return rt.Condition("all", [parse_condition_value(condition)])
     elif isinstance(condition, dict):
         keys = list(condition.keys())
-        if len(condition) == 1 and keys[0] in ['any', 'all']:
+        if len(condition) == 1 and keys[0] in ["any", "all"]:
             when = keys[0]
-            return rt.Condition(when, [parse_condition_value(c) for c in condition[when]])
+            return rt.Condition(
+                when, [parse_condition_value(c) for c in condition[when]]
+            )
         else:
-            raise Exception(f'Condition should have one of any or all: {condition}')
+            raise Exception(
+                f"Condition should have one of any or all: {condition}"
+            )
 
     else:
-        raise Exception(f'Unsupported condition {condition}')
+        raise Exception(f"Unsupported condition {condition}")
