@@ -1,13 +1,27 @@
-from durable.lang import m, c, assert_fact, ruleset, rule, when_all, post
-import durable.lang
-import yaml
-import os
 import asyncio
-import pytest
-import multiprocessing as mp
+import os
+from queue import Queue
 
+if os.environ.get("RULES_ENGINE", "durable_rules") == "drools":
+    from ansible_events.drools.vendor import lang
+    from ansible_events.drools.vendor.lang import (
+        assert_fact,
+        c,
+        m,
+        post,
+        rule,
+        ruleset,
+        when_all,
+    )
+else:
+    from durable import lang
+    from durable.lang import assert_fact, c, m, post, rule, ruleset, when_all
+
+import pytest
+import yaml
+
+from ansible_events.rule_generator import generate_rulesets
 from ansible_events.rules_parser import parse_rule_sets
-from ansible_events.rule_generator import generate_host_rulesets
 
 HERE = os.path.dirname(os.path.abspath(__file__))
 
@@ -42,11 +56,16 @@ def test_m():
     assert (
         (m.x == "lives") & (m.y == "water") & (m.subject == c.first.subject)
     ).define() == {
-        "$and": [{"x": "lives"}, {"y": "water"}, {"subject": {"first": "subject"}}]
+        "$and": [
+            {"x": "lives"},
+            {"y": "water"},
+            {"subject": {"first": "subject"}},
+        ]
     }
     assert (
         when_all(
-            c.first << m.t == "purchase", c.second << m.location != c.first.location
+            c.first << m.t == "purchase",
+            c.second << m.location != c.first.location,
         )
     ).define() == {
         "all": [
@@ -61,15 +80,15 @@ def test_ruleset():
     some_rules = ruleset("test_rules")
 
     assert some_rules
-    assert durable.lang._rulesets
-    assert durable.lang._rulesets["test_rules"] == some_rules
+    assert lang._rulesets
+    assert lang._rulesets["test_rules"] == some_rules
 
-    assert len(durable.lang._ruleset_stack) == 0
+    assert len(lang._ruleset_stack) == 0
 
     with some_rules:
-        assert durable.lang._ruleset_stack[-1] == some_rules
+        assert lang._ruleset_stack[-1] == some_rules
 
-    assert len(durable.lang._ruleset_stack) == 0
+    assert len(lang._ruleset_stack) == 0
 
     assert some_rules.define() == ("test_rules", {})
 
@@ -79,13 +98,13 @@ def test_rules():
     some_rules = ruleset("test_rules1")
 
     assert some_rules
-    assert durable.lang._rulesets
-    assert durable.lang._rulesets["test_rules1"] == some_rules
+    assert lang._rulesets
+    assert lang._rulesets["test_rules1"] == some_rules
 
-    assert len(durable.lang._ruleset_stack) == 0
+    assert len(lang._ruleset_stack) == 0
 
     with some_rules:
-        assert durable.lang._ruleset_stack[-1] == some_rules
+        assert lang._ruleset_stack[-1] == some_rules
 
         def x(c):
             print("c")
@@ -93,7 +112,7 @@ def test_rules():
         # when_all(m.x == 5)(x)
         rule("all", True, m.x == 5)(x)
 
-    assert len(durable.lang._ruleset_stack) == 0
+    assert len(lang._ruleset_stack) == 0
 
     assert some_rules.define() == (
         "test_rules1",
@@ -110,7 +129,11 @@ def test_assert_facts():
 
         @when_all(+m.subject.x)
         def output(c):
-            print("Fact: {0} {1} {2}".format(c.m.subject.x, c.m.predicate, c.m.object))
+            print(
+                "Fact: {0} {1} {2}".format(
+                    c.m.subject.x, c.m.predicate, c.m.object
+                )
+            )
 
     assert_fact(
         "test_assert_facts",
@@ -120,31 +143,32 @@ def test_assert_facts():
 
 def test_parse_rules():
     os.chdir(HERE)
-    with open("rules.yml") as f:
+    with open("rules/rules.yml") as f:
         data = yaml.safe_load(f.read())
 
-    rulesets = parse_rule_sets(data)
+    parse_rule_sets(data)
 
 
 @pytest.mark.asyncio
 async def test_generate_rules():
     os.chdir(HERE)
-    with open("rules.yml") as f:
+    with open("rules/rules.yml") as f:
         data = yaml.safe_load(f.read())
-    with open("inventory.yml") as f:
+    with open("playbooks/inventory.yml") as f:
         inventory = yaml.safe_load(f.read())
 
     rulesets = parse_rule_sets(data)
     print(rulesets)
     ruleset_queue_plans = [
-        (ruleset, mp.Queue(), asyncio.Queue()) for ruleset in rulesets
+        (ruleset, Queue(), asyncio.Queue()) for ruleset in rulesets
     ]
-    durable_rulesets = generate_host_rulesets(ruleset_queue_plans, dict(), inventory)
+    durable_rulesets = generate_rulesets(
+        ruleset_queue_plans, dict(), inventory
+    )
 
     print(durable_rulesets[0][0].define())
-    print(durable_rulesets[0][1][0].define())
 
-    assert_fact("Demo rules_localhost", {"payload": {"text": "hello"}})
+    assert_fact("Demo rules", {"payload": {"text": "hello"}})
 
     assert ruleset_queue_plans[0][2].get_nowait()[1] == "slack"
     assert ruleset_queue_plans[0][2].get_nowait()[1] == "assert_fact"
@@ -154,59 +178,77 @@ async def test_generate_rules():
 @pytest.mark.asyncio
 async def test_generate_rules_multiple_conditions_any():
     os.chdir(HERE)
-    with open("rules_with_multiple_conditions.yml") as f:
+    with open("rules/rules_with_multiple_conditions.yml") as f:
         data = yaml.safe_load(f.read())
-    with open("inventory.yml") as f:
+    with open("playbooks/inventory.yml") as f:
         inventory = yaml.safe_load(f.read())
 
     rulesets = parse_rule_sets(data)
     print(rulesets)
     ruleset_queue_plans = [
-        (ruleset, mp.Queue(), asyncio.Queue()) for ruleset in rulesets
+        (ruleset, Queue(), asyncio.Queue()) for ruleset in rulesets
     ]
-    durable_rulesets = generate_host_rulesets(ruleset_queue_plans, dict(), inventory)
+    durable_rulesets = generate_rulesets(
+        ruleset_queue_plans, dict(), inventory
+    )
 
     print(durable_rulesets[0][0].define())
-    print(durable_rulesets[0][1][0].define())
 
-    post(
-        "Demo rules multiple conditions any",
-        {"payload": {"provisioningState": "Succeeded"}},
-    )
-    assert ruleset_queue_plans[0][2].get_nowait()[1] == "slack"
-    post(
-        "Demo rules multiple conditions any", {"payload": {"provisioningState": "Deleted"}}
-    )
-    assert ruleset_queue_plans[0][2].get_nowait()[1] == "slack"
+    post("Demo rules multiple conditions any", {"i": 0})
+    assert ruleset_queue_plans[0][2].get_nowait()[1] == "debug"
+    post("Demo rules multiple conditions any", {"i": 1})
+    assert ruleset_queue_plans[0][2].get_nowait()[1] == "debug"
+
 
 @pytest.mark.asyncio
 async def test_generate_rules_multiple_conditions_all():
     os.chdir(HERE)
-    with open("rules_with_multiple_conditions2.yml") as f:
+    with open("rules/rules_with_multiple_conditions2.yml") as f:
         data = yaml.safe_load(f.read())
-    with open("inventory.yml") as f:
+    with open("playbooks/inventory.yml") as f:
         inventory = yaml.safe_load(f.read())
 
     rulesets = parse_rule_sets(data)
     print(rulesets)
     ruleset_queue_plans = [
-        (ruleset, mp.Queue(), asyncio.Queue()) for ruleset in rulesets
+        (ruleset, Queue(), asyncio.Queue()) for ruleset in rulesets
     ]
-    durable_rulesets = generate_host_rulesets(ruleset_queue_plans, dict(), inventory)
+    durable_rulesets = generate_rulesets(
+        ruleset_queue_plans, dict(), inventory
+    )
 
     print(durable_rulesets[0][0].define())
-    print(durable_rulesets[0][1][0].define())
 
-    post(
-        "Demo rules multiple conditions all",
-        {"payload": {"provisioningState": "Succeeded"}},
-    )
+    post("Demo rules multiple conditions all", {"i": 0})
     assert ruleset_queue_plans[0][2].qsize() == 0
-    post(
-        "Demo rules multiple conditions all",
-        {"payload": {"provisioningState": "Deleted"}},
-    )
+    post("Demo rules multiple conditions all", {"i": 1})
     assert ruleset_queue_plans[0][2].qsize() == 1
-    assert ruleset_queue_plans[0][2].get_nowait()[1] == "slack"
+    assert ruleset_queue_plans[0][2].get_nowait()[1] == "debug"
 
 
+@pytest.mark.asyncio
+async def test_generate_rules_multiple_conditions_all_3():
+    os.chdir(HERE)
+    with open("rules/rules_with_multiple_conditions3.yml") as f:
+        data = yaml.safe_load(f.read())
+    with open("playbooks/inventory.yml") as f:
+        inventory = yaml.safe_load(f.read())
+
+    rulesets = parse_rule_sets(data)
+    print(rulesets)
+    ruleset_queue_plans = [
+        (ruleset, Queue(), asyncio.Queue()) for ruleset in rulesets
+    ]
+    durable_rulesets = generate_rulesets(
+        ruleset_queue_plans, dict(), inventory
+    )
+
+    print(durable_rulesets[0][0].define())
+
+    post("Demo rules multiple conditions reference assignment", {"i": 0})
+    assert ruleset_queue_plans[0][2].qsize() == 0
+    post("Demo rules multiple conditions reference assignment", {"i": 1})
+    assert ruleset_queue_plans[0][2].qsize() == 0
+    post("Demo rules multiple conditions reference assignment", {"i": 2})
+    assert ruleset_queue_plans[0][2].qsize() == 1
+    assert ruleset_queue_plans[0][2].get_nowait()[1] == "debug"
